.. SPDX-FileCopyrightText: 2025 Contributors to the OpenSTEF project <openstef@lfenergy.org>
..
.. SPDX-License-Identifier: MPL-2.0

.. _support:

Support
----------------------------
There are a few ways to connect with the OpenSTEF project:

* Join the **#openstef channel**, which is part of the `LF Energy Slack workspace <https://slack.lfenergy.org/>`_.
  * Depending on your work e-mail address, you may need to be invited in order to join the Slack workspace. If this is the case, please e-mail ``openstef@lfenergy.org``. We are happy to invite you.
* Send a **direct message** to one of the most recent `contributors <https://github.com/OpenSTEF/openstef/graphs/contributors>`_.
* Submit an **issue** at `GitHub <https://github.com/OpenSTEF/openstef/issues>`_.
* Join the four-weekly **community meeting**. You can find information, including meeting invite links, on `our wiki page <https://wiki.lfenergy.org/display/OS/Four-weekly+community+meeting>`_.

How to ask for help
^^^^^^^^^^^^^^^^^^^

If you have trouble installing, building, or using OpenSTEF, but there's no reason yet to suspect you have encountered a genuine bug, start by posting a question to the **Slack channel**. This is the place for questions such as "How do I...".

How to report a bug or request an enhancement
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

This project manages bugs and enhancements using the `GitHub issue tracker <https://github.com/OpenSTEF/openstef/issues>`_. The issue template will guide you on making an effective report.

How to report a security vulnerability
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

If you think you have found a potential vulnerability in this project, please e-mail ``openstef@lfenergy.org`` to responsibly disclose it.
